#!/bin/sh

basedir=`pwd`

user=tipadmin
passwd=tippass
if [ ! -z "$1" ]; then
	user=$1
fi
if [ ! -z "$2" ]; then
	passwd=$2
fi
base="7.3.0"
fixpack="4"
full="${base}.${fixpack}"

echo "Searching for installed components..."

de=""
for dir in $SI_PATH/bin $HOME/.acsi_$USER/bin /usr/ibm/common/acsi/bin
do
	if [ -x $dir/de_lsrootiu.sh ]; then
		de=$dir
		break
	fi
done
if [ -z "$de" ]; then
	echo "Unable to find DE"
	exit 1
fi

patched=0
oifs="$IFS"
tipinfo=`$de/de_lsrootiu.sh | grep "IU,TIPCore" | awk -F, '{print $4 " " $5}'`
set -- $tipinfo
tipver=$1
TIP_HOME=$2
IFS="."
set -- $tipver
IFS="$oifs"
if [ "$1.$2.$3" == "2.2.0" ] && [ "$4" -lt 5 ]; then
	echo "TUAM is not supported on TIP $tipver - please apply TIP 2.2 fix pack 5"
	echo "before applying this TUAM fix pack."
	exit 1
fi

${TIP_HOME}/profiles/TIPProfile/bin/serverStatus.sh server1 -username $user -password $passwd | grep -q ADMU0508I
if [ $? -ne 0 ]; then
	echo "Unable to check TIP server status - please ensure server is running"
	echo "and check $user password is correct."
	echo
	echo "usage: $0 tipadmin password"
	exit 1
fi

$de/de_lsrootiu.sh | grep "IU,TUAM_" | sort | (while read line
do
	IFS=","
	set `echo "$line" | awk -F, '{print $2 "," $4 "," $5 "," $6}' | sed 's/]<.*//'`
	IFS="$oifs"
	component=$1
	version=$2
	disc=$3
	uuid=$4
	installedbase=`echo $version | awk -F. '{print $1 "." $2 "." $3}'`
	installedfp=`echo $version | awk -F. '{print $NF}'`
	if [ "$installedbase" == "$base" ] && [ "$installedfp" -lt "$fixpack" ] && [ -d $basedir/$component/META-INF ]; then
		echo "Applying patch for $component"
		cd $basedir/$component/META-INF
		. $disc/bin/setupEnv.sh
		if [ "$component" == "TUAM_UI" ]; then
			cat > var.properties <<EOF
Variable#RootIUTypeID[${uuid},${full}]#IAGLOBAL_TIP_HOME=${TIP_HOME}
Variable#RootIUTypeID[${uuid},${full}]#shExt=sh
Variable#RootIUTypeID[${uuid},${full}]#IAGLOBAL_WASUserID=$user
Variable#RootIUTypeID[${uuid},${full}]#IALOCAL_WASPassword=$passwd
EOF
			$de/manageIU.sh -o update -u true -i var.properties -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			status=$?
			rm -f var.properties
			mkdir -p $TUAM_HOME/_uninst/fixes/fp${fixpack}
			if [ "$tipver" == "2.2.0.5" ]; then
				cp ${TIP_HOME}/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/SMUtils.js $TUAM_HOME/_uninst/ffixes/p${fixpack}/
				cp ../FILES/SMUtils_2.2.0.5.js ${TIP_HOME}/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/SMUtils.js
			fi
			if [ $status -eq 0 ]; then
				${TIP_HOME}/profiles/TIPProfile/bin/tipRegister.sh -getVersion 081F67AF608643DE937B00F6A41D9083 > $TUAM_HOME/_uninst/fixes/fp${fixpack}/tipregistry.txt
				if [ $? -ne 0 ]; then
					rm $TUAM_HOME/_uninst/fixes/fp${fixpack}/tipregistry.txt
				fi
				${TIP_HOME}/profiles/TIPProfile/bin/tipRegister.sh 081F67AF608643DE937B00F6A41D9083 TUAM $TUAM_HOME ${full} product none false >> $TUAM_HOME/logs/fp_${component}.log 2>&1
				status=$?
			fi
		else
			$de/manageIU.sh -o update -r $TUAM_HOME -p packagedIU.xml -u true >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			status=$?
		fi
		if [ $status -ne 0 ]; then
			echo "Patch failed"
			exit 1
		fi
		mkdir -p $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component
		cp * $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component
		patched=1
	fi
done
if [ $patched -eq 0 ]; then
   echo "TUAM Release ${base}.0 to ${base}.`expr $fixpack - 1` must be installed to install this fix pack."
   echo "Please install this version before attempting to install this fix pack."
   echo "Fix has not been applied successfully."
   exit 1
fi
)

