#------------------------------------------------------------------------------
# TUAM script for creating a shared library.
# The shared library is associated with the classloader of the
# application server, so all applications running in the application
# server will use the same classes in the shared library.
#
# IBM Tivoli Usage and Accounting Manager
# AUC
# (C) Copyright IBM Corp. 2011
#
# Creating shared library:
# wsadmin -lang jython -f createSharedLib.py
#------------------------------------------------------------------------------
import sys

# variables used below
global AdminConfig
global AdminControl

#----------------------------------------------------------------------------
# definition of the getNodeId routine
#
# parameters:
#
# nodeName - the name of the node containing the server
#---------------------------------------------------------------------------
def getNodeId(nodeName):
   # make sure the node exists
   fullNodeName = "/Node:" + nodeName + "/"
   print "Looking for Node: " + fullNodeName
   nodeId = AdminConfig.getid(fullNodeName)
   if len(nodeId) == 0:
	  print "   Exiting because the Node was not found"
	  return None
   else:
	  print "   Found Node: "  + nodeId
	  return nodeId	

#----------------------------------------------------------------------------
# definition of the getAppId routine
#
# parameters:
#
# app - the name of the app to configure 
#---------------------------------------------------------------------------
def getAppId(app):
   appId = AdminConfig.getid('/Deployment:' + app + '/');
   return appId

#----------------------------------------------------------------------------
# definition of the createLibrary routine
#
# parameters:
#
# nodeId	 - the id of the node containing the server
# shLibName  - the name of the shared library
# shLibDesc  - the description of the shared library
# shLibValue - the value of the shared library including the fully qualified path to the jars
#			  if there are more than one jars, the user of this script is responsible for constructing
#			  this value (ie, E:/ibm/tivoli/tip/coreapi.jar;E:/ibm/tivoli/tip/engineapi.jar; )
#---------------------------------------------------------------------------
def createLibrary(nodeId, shLibName, shLibDesc, shLibValue):
   print "Creating Library"
   libraryId = AdminConfig.create('Library', nodeId, [['name', shLibName], ['description',shLibDesc], ['classPath', shLibValue] , ['isolatedClassLoader', 'true']])
   print "   Created Library: " + libraryId
   return libraryId

#----------------------------------------------------------------------------
# definition of the getClassLoaders routine
#
# parameters:
#
# appId - the application id used to retrieve the classloaders 
#---------------------------------------------------------------------------
def getClassLoaders(appId):
   print "Looking for Classloader for the Application " + appId
   classLoaderIds = AdminConfig.list('Classloader',appId).split(lineSeparator)
   return classLoaderIds

#----------------------------------------------------------------------------
# definition of the createClassLoader routine
#
# parameters:
#
# appId - the application Id used to retrieve the classloaders
# libraires - the list of librarys to add to the classloader
# mode	   - the mode for the classLoader 'PARENT_LAST' or 'PARENT_FIRST'
#---------------------------------------------------------------------------
def createClassLoader(appId, libraries, mode):
   classLoaderId = AdminConfig.create('Classloader', appId, [['libraries', libraries ], ['mode', mode]])
   print "	  Created Classloader: " + classLoaderId
   return classLoaderId

#----------------------------------------------------------------------------
# definition of the createLibraryRef routine
#
# parameters:
#
# classLoaderId - the id of a classloader for an application or server
# shLibName	 - the name of the shared library to create a reference for
# isShared	  - determines if the classloader is shared
#---------------------------------------------------------------------------
def createLibraryRef(classLoaderId, shLibName, isShared):
   print "Creating LibraryRef"
   libraryRefId = AdminConfig.create('LibraryRef', classLoaderId, [['libraryName', shLibName],  ['sharedClassloader', isShared]])
   print "   Created LibraryRef: " + libraryRefId
   return libraryRefId

#------------------------------------------------------------------------------
# definition of the search routine
#
# parameters:
# 
# shLibName   - the name of the node shared library
# 
#----------------------------------------------------------------------------
def search(shLibName):
	existingLibraryIds = AdminConfig.list('Library').split(lineSeparator)
	print "Found number of existing Libraries: %s" % (len(existingLibraryIds))
	for existingLibraryId in existingLibraryIds:
		if len(existingLibraryId) > 0:
			existingLibraryName = AdminConfig.showAttribute(existingLibraryId, 'name')
			print "	  Library name: " + existingLibraryName
			if existingLibraryName == shLibName:
				return existingLibraryId
	return None


#---------------------------------------------------------------------------------
# definition of the addShLib routine
#
# parameters:
# 
# shLibName  - the name of the shared library
# app		- the application to apply the shared library to
# mode	   - the mode for the classLoader 'PARENT_LAST' or 'PARENT_FIRST'
# isShared   - determins wheter the shLib classloader is shared 'true' or 'false' 
#---------------------------------------------------------------------------------
def addShLib(shLibName, app, mode, isShared):

   #get app id
   appId = getAppId(app)
   print "	  APP name: " + app
   print "	  APP ID: " + appId
   # look for the classloader for the application
   classLoaderIds = getClassLoaders(appId)
	
   classLoaderId = None
   # create the classloader if it does not exist
   if len(classLoaderIds) == 0:
	  print "   Did not find Classloader, creating a new Classloader"
	  classLoaderId = createClassLoader(appId, [], mode)
   else:
	  classLoaderId = classLoaderIds[0]
	  print "   Found Classloader: " + classLoaderId

   # create library ref associating appserver class to shared library
   print "Creating LibraryRef"
   libraryRefId = createLibraryRef(classLoaderId, shLibName, isShared)

#------------------------------------------------------------
# definition of the createrxaShLib routine
#
# installDir - the installation directory of aucConsole
# nodeId	 - the node id containing the server
# app		- the application to associate the libray with
#------------------------------------------------------------
def createRxaShLib(installDir, nodeId, app):
   #Classloader options
   PARENT_LAST = 'PARENT_LAST'
   PARENT_FIRST = 'PARENT_FIRST'
   TRUE = 'true'
   FALSE = 'false'   

   #rxa SHARED LIBRARY VARS
   rxaShLibName  = "RXA_SH_LIB"
   rxaShLibDesc  = "A shared library that represents the RXA jar"
   rxaShLibValue = installDir + "/WEB-INF/lib/remoteaccess.jar;" + installDir + "/WEB-INF/lib/ssh.jar;" + installDir + "/WEB-INF/lib/jlanclient.jar;" + installDir + "/WEB-INF/lib/vim25.jar"
   successMsgrxa = "Shared library " + rxaShLibName + " installed correctly on "

   #Check for library already existing
   libId = search(rxaShLibName)
   if libId != None:
	  print rxaShLibName + " already exists! Updating..."
	  AdminConfig.modify(libId, [['classPath', '']])
	  AdminConfig.modify(libId, [['classPath', rxaShLibValue]])
	  return 1
	
   #Create the library
   rxaLibraryId = createLibrary(nodeId, rxaShLibName, rxaShLibDesc, rxaShLibValue)
   #Add the shared library to the application
   addShLib(rxaShLibName, app, PARENT_FIRST, TRUE)
   print "Finished executing addShLib function"

   print "Verifying the installation, if the library was installed correctly successMsg would be printed"
   if search(rxaShLibName) == None:
	  sys.stderr.write("Shared library was not installed correctly\n")
	  return 0
	  
   print successMsgrxa + app	
   return 1

#------------------------------------------------------------------------------
# Get the directory, as a string, where WAS is installed.
#------------------------------------------------------------------------------
def getWASHome(cell, node):
	varMap = AdminConfig.getid("/Cell:" + cell + "/Node:" + node + "/VariableMap:/")
	entries = AdminConfig.list("VariableSubstitutionEntry", varMap)
	eList = entries.splitlines()
	for entry in eList:
		name =  AdminConfig.showAttribute(entry, "symbolicName")
		print name
		if name == "WAS_INSTALL_ROOT":
			value = AdminConfig.showAttribute(entry, "value")
			return value
	#failover
	return java.lang.System.getenv('WAS_HOME')

#------------------------------------------------------------------------------
# Get the directory, as a string, of the isclite.ear application.
#
# The isc.ear is located in <WAS_HOME>/profiles/TIPProfile/installedApps/TIPCell/isc.ear
#------------------------------------------------------------------------------
def getISCFile(cell, node):
	fileSep = getFileSep(node)
	return fileSep.join([getWASHome(cell, node), "profiles", "TIPProfile", "installedApps", cell, "isc.ear", "aucConsole.war"])
	
#------------------------------------------------------------------------------
# Get the file separator character
#
# This gets the file separator for the node in which we plan to install the
# console.  Therefore we can't just use the value that python on Java gives
# us.  Instead, check the platform of the node, and use "\" for windows and
# "/" for everything else.
#------------------------------------------------------------------------------
def getFileSep(node):
	os = AdminTask.getNodePlatformOS("-nodeName " + node)
	if os == 'windows':
		return '\\'
	else:
		return '/'
		
#------------------------------------------------------------------------------
# Get a tuple containing the cell, node, server name, and type
#------------------------------------------------------------------------------
def getCellNodeServer():
	servers = AdminConfig.list("Server").splitlines()
	for serverId in servers:
		serverName = serverId.split("(")[0]
		server = serverId.split("(")[1]  #remove name( from id
		server = server.split("/")
		cell = server[1]
		node = server[3]
		cellId = AdminConfig.getid("/Cell:" + cell + "/")
		cellType = AdminConfig.showAttribute(cellId, "cellType")
		if cellType == "DISTRIBUTED":
			if AdminConfig.showAttribute(serverId, "serverType") == "DEPLOYMENT_MANAGER":
				return (cell, node, serverName, "DEPLOYMENT_MANAGER")
		elif cellType == "STANDALONE":
			if AdminConfig.showAttribute(serverId, "serverType") == "APPLICATION_SERVER":
				return (cell, node, serverName, "APPLICATION_SERVER")
	return None
	
#------------------------------------------------------------------------------
# Create the shared libraries
#------------------------------------------------------------------------------
def createSharedLib():
	# Initialize the values necessary to create shared library
	# The shared library value will have to be changed based on the install root
	# that was specified by the Installer's user. i.e. replace C: with the
	# value of the directory specified by user
	topology = getCellNodeServer()
	if topology == None:
		sys.stderr.write("Could not find suitable server\n")
		if failOnError == "true":
			sys.exit(105)
	else:
		cell = topology[0]
		node = topology[1]
		server = topology[2]
		type = topology[3]
		
		# path to the deployed war
		warFile = getISCFile(cell,node)

		# get the node id
		nodeId = getNodeId(node)
		if ( nodeId == None or len(nodeId) == 0 ):
		   sys.stderr.write("Could not find the node\n")
		   sys.exit(103)

		#Application Name
		aucConsoleApp = "isc"

		retVal = createRxaShLib(warFile, nodeId, aucConsoleApp)
		if retVal == 1:
			AdminConfig.save()
		else:
			print "Skipping Config Save"
			if failOnError == "true":
				sys.exit(109)
				
				
#------------------------------------------------------------------------------
# Main entry point
#------------------------------------------------------------------------------

# Uncomment the following line to enable tracing to the wsadmin.traceout file
# AdminControl.trace('com.ibm.*=all=enabled')

createSharedLib()
