#!/bin/sh
#   *************************************************************** {COPYRIGHT-TOP}
#   * Licensed Materials - Property of IBM
#   * Restricted Materials of IBM
#   * IBM Tivoli Usage and Accounting Manager
#   * 5724-O33, 5765-UAV, 5765-UA7, 44E7863
#   * (c) Copyright IBM Corp. 2004, 2007 All Rights Reserved.
#   *
#   * US Government Users Restricted Rights - Use, duplication or
#   * disclosure restricted by GSA ADP Schedule Contract with
#   * IBM Corp.
#   **************************************************************** {COPYRIGHT-END}
#
#   ****************************************************************
#   * TUAM deploy/undeploy/redeploy Installation Script
#   *
#   *    If WAS security is enabled, then a username and password are
#   *    required to stop the server.  If security is disabled, then
#   *    any supplied user and password are ignored by WAS.
#   *
#   * Usage: deployTuam.sh  install | remove | replace [user] [password]
#   ****************************************************************

#
# Setup Global Commands, Resources, and Variables
#
INTERP=`uname -s`
ECHO="echo"

. `dirname $0`/../../bin/setupEnv.sh
export TIP_HOME

error()
{
	echo deployTuam failed!  Exiting with error: $RETCODE
	exit $RETCODE
}

#
# Setup Interp Specific Commands, Resources, and Variables
#
if [ "${INTERP}" = "Linux" ]; then
	ECHO="echo -e"
fi

PROFILE=TIPProfile
user=default
PASSWORD=default

USAGE="Usage:\n\
\tdeployTuam.sh install [user] [password]\n\
\tdeployTuam.sh remove  [user] [password]\n\
\tdeployTuam.sh replace [user] [password]"


if [ -n "${1}" ]; then

	if [ "${1}" != "install" ] && [ "${1}" != "replace" ] && [ "${1}" != "remove" ] ; then
		#
		# Invalid option
		#
		${ECHO} "\"${1}\" is an invalid option"
		${ECHO} ${USAGE}
		exit 2

	fi

	if [ -n "${2}" ]; then
		user=${2}
	fi

	if [ -n "${3}" ]; then
		PASSWORD=${3}
	fi

	cd ${TUAM_HOME}
	#cp setup/console/aucConsole.war setup/console/aucConsoleAUIML.war
	${TIP_HOME}/profiles/${PROFILE}/bin/wsadmin.sh -f ${TUAM_HOME}/setup/console/deployTUAMConsole.py $1 lib -user "${user}" -password "${PASSWORD}"
	RETCODE=$?
	#rm setup/console/aucConsoleAUIML.war
	if [ "$RETCODE" -ne "0" ]; then
		error
	fi

else
	${ECHO} ${USAGE}
	exit 1
fi





