REM ****************************************************************
REM * Licensed Materials - Property of IBM
REM * IBM Tivoli Usage and Accounting Manager
REM * 5724-O33, 5765-UAV, 5765-UA7, 44E7863
REM * (C) Copyright IBM Corp. 2005, 2007
REM *
REM * The source code for this program is not published or otherwise
REM * divested of its trade secrets, irrespective of what has been
REM * deposited with the U.S. Copyright Office.
REM *****************************************************************
REM
REM *****************************************************************
REM * This script is run to configure TUAM web reporting in IIS.
REM *
REM * Syntax:
REM *    iisconfig.vbs web2|financialmodeler install|uninstall [default|virtual]
REM *****************************************************************

Option Explicit
On Error Resume Next

Const TUAMUSERS_GROUP = "TUAMUSERS"
Const ASPNET_USER = "ASPNET"

Const DEFAULT_PATH = "IIS://localhost/W3SVC/1/ROOT"
Const VIRTUAL_PATH = "IIS://localhost/W3SVC/1/ROOT/TUAM"
Const FIN_MOD_PATH = "IIS://localhost/W3SVC/1/ROOT/FinancialModeler"
Const PRODUCT_WEB2       = "web2"
Const PRODUCT_FINMODELER = "financialmodeler"          

Const LOCATION_DEFAULT = "default"
Const LOCATION_VIRTUAL = "virtual"

Const ACTION_INSTALL   = "install"
Const ACTION_UNINSTALL = "uninstall"

Const GENERAL_FAILURE = 2
Const GENERAL_WARNING = 1

Const AppCreate_InProc = 0
Const AppCreate_OutOfProc = 1
Const AppCreate_PooledOutOfProc = 2

Dim Product
Dim Action
Dim Location

Dim WebSiteObject
Dim WebVirtualObject
Dim VirtualObject
Dim fso
Dim shell

Call GetArgs()

Set fso = CreateObject("Scripting.FileSystemObject")
Set shell = WScript.CreateObject("WScript.Shell")

If Action = ACTION_INSTALL Then
    If CreateLocalUserGroup(TUAMUSERS_GROUP) Then        
        'Add users to group
        Call AddUserToLocalGroup(TUAMUSERS_GROUP, GetNetWorkServiceAccount())
        Call AddUserToLocalGroup(TUAMUSERS_GROUP, ASPNET_USER)
        'Set permissions on config and logs directories 
        Call GrantChangePermission(GetConfigDirectory(), TUAMUSERS_GROUP)
        Call GrantChangePermission(GetLogsDirectory, TUAMUSERS_GROUP)        
    End If 
End If
If Action = ACTION_UNINSTALL Then
    'Remove TUAMUSERS local group
    Call DeleteLocalUserGroup(TUAMUSERS_GROUP)  
End If

If Product = PRODUCT_WEB2 AND Action = ACTION_INSTALL Then

    'Set permissions on report and config directories 
    Call GrantChangePermission(GetReportsMSRS2Directory(), TUAMUSERS_GROUP) 
    
    If Location = LOCATION_VIRTUAL Then
    
        If (ObjectExists(VIRTUAL_PATH)=false) Then        
            Set WebSiteObject = GetObject(DEFAULT_PATH)
            If (Err.Number <> 0) Then            
                WScript.Echo "Error Accessing Default Web Site"            
                WScript.Quit (Err.Number)
            End If  
                  
            Set WebVirtualObject = WebSiteObject.Create("IIsWebVirtualDir", "TUAM") 
            WebVirtualObject.SetInfo        
            If Err.Number <> 0 Then
                WScript.Echo "Error Creating TUAM Virtual Directory"
                WScript.Quit(Err.Number)
            End If                 
                    
            WScript.Echo "TUAM Virtual Directory Created."    
        End If
                
        Call UpdateWebInfo(VIRTUAL_PATH)     
    
    ElseIf Location = LOCATION_DEFAULT Then
    
        Call UpdateWebInfo(DEFAULT_PATH)
        
    End If

ElseIf Product = PRODUCT_WEB2 AND Action = ACTION_UNINSTALL Then
            
    'Check for Virtual directory
    If (ObjectExists(VIRTUAL_PATH)) Then    
        
        Set VirtualObject = GetObject(VIRTUAL_PATH)
        Set WebSiteObject = GetObject(DEFAULT_PATH)

        If (VirtualObject.AppFriendlyName = "TUAM Web") Then
        
            Call WebSiteObject.Delete("IIsObject", "TUAM")

            If Err.Number <> 0 Then
                WScript.Echo "Error Removing TUAM Virtual Directory."
                WScript.Quit (Err.Number)
            End If 
            
            WScript.Echo "TUAM Virtual Directory Removed." 
        End If      
    End If      

    'Check for default 
    If (ObjectExists(DEFAULT_PATH)) Then    
        Set WebSiteObject = GetObject(DEFAULT_PATH)
        
        If (WebSiteObject.AppFriendlyName = "TUAM Web") Then

            WebSiteObject.Path = "C:\Inetpub\wwwroot"
            WebSiteObject.AppFriendlyName = "Default Application"
            WebSiteObject.SetInfo

            If Err.Number <> 0 Then
                WScript.Echo "Error Removing TUAM Web Application."
                WScript.Quit (Err.Number)
            End If  
            
            WScript.Echo "TUAM Web Application Removed." 
        End If    
    End If 
     
    
ElseIf Product = PRODUCT_FINMODELER AND Action = ACTION_INSTALL Then

    Call GrantChangePermission(GetFinancialModelerDirectory, TUAMUSERS_GROUP)
    
    Call CreateFinancialModeler()
            
ElseIf Product = PRODUCT_FINMODELER AND Action = ACTION_UNINSTALL Then
    
    If (ObjectExists(FIN_MOD_PATH)) Then    
        
        Set VirtualObject = GetObject(FIN_MOD_PATH)
        Set WebSiteObject = GetObject(DEFAULT_PATH)

        If (VirtualObject.AppFriendlyName = "Financial Modeler") Then
        
            Call WebSiteObject.Delete("IIsObject", "FinancialModeler")

            If Err.Number <> 0 Then
                WScript.Echo "Error Removing Financial Modeler Virtual Directory."
                WScript.Quit (Err.Number)
            End If 
            
            WScript.Echo "Financial Modeler Virtual Directory Removed." 
        End If      
    End If     
    
End If

'***********************
'* End Main Script
'***********************

Sub CreateFinancialModeler()

    On Error Resume Next
    
    Dim WebObject
    Dim SiteObject

    If (ObjectExists(FIN_MOD_PATH)=false) Then        
        Set WebObject = GetObject(DEFAULT_PATH)
        If (Err.Number <> 0) Then            
            WScript.Echo "Error Accessing Default Web Site"            
            WScript.Quit (Err.Number)
        End If  
              
        Set SiteObject = WebObject.Create("IIsWebVirtualDir", "FinancialModeler") 
        SiteObject.SetInfo        
        If Err.Number <> 0 Then
            WScript.Echo "Error Creating Financial Modeler Virtual Directory"
            WScript.Quit(Err.Number)
        End If                 
                
        WScript.Echo "Financial Modeler Virtual Directory Created." 
    Else
        Set SiteObject = GetObject(FIN_MOD_PATH)  
    End If
        
    If (Err.Number <> 0) Then
        WScript.Echo "Error Accessing Financial Modeler Web Site."
        WScript.Quit (Err.Number)
    End If  
    
    If (IIsMajorVersion() > 5) Then
        Call SiteObject.AppCreate3(AppCreate_PooledOutOfProc, "TUAM Pool", True)
    Else 
        Call SiteObject.AppCreate2(AppCreate_PooledOutOfProc)
    End If     

    If (Err.Number <> 0) Then
        WScript.Echo "Error Creating Financial Modeler Application."
        WScript.Quit (Err.Number)
    End If 
    
    WScript.Echo "Financial Modeler Application Created." 
        
    SiteObject.AppEnable
    
    If (Err.Number <> 0) Then
        WScript.Echo "Error Enabling Financial Modeler Application."
        WScript.Quit (Err.Number)
    End If

    WScript.Echo "Financial Modeler Application Enabled."             
        
    SiteObject.Path = GetFinancialModelerDirectory()
    SiteObject.AppFriendlyName = "Financial Modeler"
    SiteObject.DefaultDoc = "default.htm"
    SiteObject.EnableDefaultDoc = True 
    SiteObject.AccessScript = True   
    SiteObject.AccessRead = True
    SiteObject.AccessWrite = False
    SiteObject.EnableDirBrowsing = False
    SiteObject.AuthNTLM = True
    SiteObject.AuthAnonymous = True               
    SiteObject.SetInfo
    
    If Err.Number <> 0 Then
        WScript.Echo Err.Description
        WScript.Echo "Error Updating Financial Modeler Web Site."
        WScript.Quit (Err.Number)
    End If 
    
    WScript.Echo "Financial Modeler Web Site Created."    
          
    Call AspNetRegIIS(FIN_MOD_PATH)  
    
End Sub

Sub UpdateWebInfo(SitePath)

    On Error Resume Next
    
    Dim SiteObject
    Set SiteObject = GetObject(SitePath)
    
    If (Err.Number <> 0) Then
        WScript.Echo "Error Accessing TUAM Web Site."
        WScript.Quit (Err.Number)
    End If    
    
    Dim objWMIService
		Set objWMIService = GetObject("winmgmts:\\.\root\cimv2")
	
    If InStr(retrieveOsVersion(objWMIService), "Microsoft Windows Server 2008 R2") Then
     Dim AppPools, newAppPool    
     set AppPools = GetObject("IIS://localhost/w3svc/AppPools")   
     Call SiteObject.AppCreate3(AppCreate_PooledOutOfProc, "TUAM Pool", True)
     set newAppPool = GetObject("IIS://localhost/w3svc/AppPools/TUAM Pool")
     newAppPool.AppPoolIdentityType=0
     newAppPool.enable32BitAppOnWin64=0
     newAppPool.SetInfo    
    ElseIf (IIsMajorVersion() > 5) Then
        Call SiteObject.AppCreate3(AppCreate_PooledOutOfProc, "TUAM Pool", True)
    Else 
        Call SiteObject.AppCreate2(AppCreate_PooledOutOfProc)
    End If     

    If (Err.Number <> 0) Then
        WScript.Echo "Error Creating TUAM Application."
        WScript.Quit (Err.Number)
    End If 
    
    WScript.Echo "TUAM Application Created." 
        
    SiteObject.AppEnable
    
    If (Err.Number <> 0) Then
        WScript.Echo "Error Enabling TUAM Application."
        WScript.Quit (Err.Number)
    End If

    WScript.Echo "TUAM Application Enabled."             
    
    SiteObject.Path = GetWebDirectory()
    SiteObject.AppFriendlyName = "TUAM Web"
    SiteObject.DefaultDoc = "default.aspx"
    SiteObject.EnableDefaultDoc = True 
    SiteObject.AccessScript = True   
    SiteObject.AccessRead = True
    SiteObject.AccessWrite = False
    SiteObject.EnableDirBrowsing = False
    SiteObject.AuthNTLM = True
    SiteObject.AuthAnonymous = True               
    SiteObject.SetInfo
    
    If Err.Number <> 0 Then
        WScript.Echo Err.Description
        WScript.Echo "Error Updating TUAM Web Site."
        WScript.Quit (Err.Number)
    End If 
    
    WScript.Echo "TUAM Web Site Created."    
          
    Call AspNetRegIIS(SitePath)  
    
End Sub

Sub GetArgs
    Dim ArgObj
    ' Get the Arguments object
    Set ArgObj = WScript.Arguments
    
    Dim arg0, arg1, arg2
    
    If ArgObj.Count = 3 Then 
        arg0 = Trim(Lcase(ArgObj(0)))
        arg1 = Trim(Lcase(ArgObj(1)))           
        arg2 = Trim(Lcase(ArgObj(2)))
        If arg0 = PRODUCT_WEB2 or arg0 = PRODUCT_FINMODELER Then
            Product = arg0
        End If
        If arg1 = ACTION_INSTALL or arg1 = ACTION_UNINSTALL Then
            Action = arg1
        End If
        If arg2 = LOCATION_DEFAULT or arg2 = LOCATION_VIRTUAL Then
            Location = arg2
        End If
    ElseIf ArgObj.Count = 2 Then
        arg0 = Trim(Lcase(ArgObj(0)))
        arg1 = Trim(Lcase(ArgObj(1)))
        If arg0 = PRODUCT_WEB2 or arg0 = PRODUCT_FINMODELER Then
            Product = arg0
        End If        
        If arg1 = ACTION_INSTALL or arg1 = ACTION_UNINSTALL Then
            Action = arg1
        End If
        Location = LOCATION_DEFAULT    
    Else
        DisplayHelpMessage
        WScript.Quit(GENERAL_FAILURE)
    End If    
End Sub

Function GetNetWorkServiceAccount()
    Dim acct
    acct = ""	
	Dim objWMIService
	Set objWMIService = GetObject("winmgmts:\\.\root\cimv2")
	Dim osVersion
    osVersion = retrieveOsVersion(objWMIService)
	Dim colAccounts
		Set colAccounts = objWMIService.ExecQuery ("Select * From Win32_Account WHERE SID = 'S-1-5-20'")	
	If InStr(osVersion, "Microsoft Windows Server 2008 R2") Then
		Set colAccounts = objWMIService.ExecQuery ("Select * From Win32_Account WHERE SID = 'S-1-5-19'")
	End If 	
	Dim objAccount
		For Each objAccount in colAccounts
			acct = objAccount.Name
			exit for
		Next	

    GetNetWorkServiceAccount = acct
End Function

Function retrieveOsVersion(objWMIService) 
    Dim colOperatingSystems
	Set colOperatingSystems = objWMIService.ExecQuery _
		("Select * from Win32_OperatingSystem")
	Dim osVersion
		osVersion = ""	
	Dim objOperatingSystem	
	For Each objOperatingSystem in colOperatingSystems
		osVersion = objOperatingSystem.Caption
		exit for
	Next
	retrieveOsVersion = osVersion
End Function	 
	

Function CreateLocalUserGroup(groupName)
    Dim cmd
    set cmd = ExecuteCommand("NET LOCALGROUP """ & groupName & """ /ADD")
    
    Wscript.Echo ReadOutput(cmd)
    
    CreateLocalUserGroup = (cmd.ExitCode = 0)    
End Function

Function DeleteLocalUserGroup(groupName)
    Dim cmd
    set cmd = ExecuteCommand("NET LOCALGROUP """ & groupName & """ /DELETE")
    
    Wscript.Echo ReadOutput(cmd)

    DeleteLocalUserGroup = (cmd.ExitCode = 0)    
End Function

Function AddUserToLocalGroup(groupName, user)
    Dim cmd
    set cmd = ExecuteCommand("NET LOCALGROUP """ & groupName & """ """ & user & """ /ADD")
    
    Wscript.Echo ReadOutput(cmd)
    
    AddUserToLocalGroup = (cmd.ExitCode = 0)    
End Function

Function RemoveUserFromLocalGroup(groupName, user)
    Dim cmd
    set cmd = ExecuteCommand("NET LOCALGROUP """ & groupName & """ """ & user & """ /DELETE")
    
    Wscript.Echo ReadOutput(cmd)
    
    RemoveUserFromLocalGroup = (cmd.ExitCode = 0)    
End Function

Function GrantChangePermission(path, user)
    GrantChangePermission = GrantNTFS(path, user, "C")
End Function

Function GrantNTFS(path, user, permission)
    Dim cmd
    set cmd = ExecuteCommand("CACLS """ & path & """ /T /E /G """ & user & """:" & permission)
    
    Wscript.Echo ReadOutput(cmd)
    
    GrantNTFS = (cmd.ExitCode = 0)    
End Function

Function ExecuteCommand(command)    

    Dim oExec
    Set oExec = shell.Exec("%comspec% /c " & command)
  
     
    set ExecuteCommand = oExec    
End Function

Sub AspNetRegIIS(path)
    Dim folder, filepath, cmd
    Dim sysdir, tmpDir
    
    path = Mid(path,17)
    
    sysdir = shell.ExpandEnvironmentStrings("%windir%")
    tmpDir = sysdir & "\Microsoft.NET\Framework64"
    If (fso.FolderExists(tmpDir) = false) Then
       tmpDir = sysdir & "\Microsoft.NET\Framework"
    End If    
    If (fso.FolderExists(tmpDir)) Then
        for each folder in fso.GetFolder(tmpDir).SubFolders
            If (left(folder.Name, 2) = "v2") Then
                filepath = folder.Path
                exit for
            End If
        next
        filepath = filepath & "\aspnet_regiis.exe"
    End If

    if (fso.FileExists(filepath)) Then
    
        Set cmd = ExecuteCommand(filepath & " -ir -enable")
        Wscript.Echo ReadOutput(cmd)
            
        set cmd = ExecuteCommand(filepath & " -sn " & path)
        Wscript.Echo ReadOutput(cmd)
               
    Else
        Wscript.Echo "Error Resolving .NET framework path." & filepath
    End If       
End Sub

Function ReadOutput(oExec)
   
     If Not oExec.StdOut.AtEndOfStream Then
          ReadOutput = oExec.StdOut.ReadAll
          Exit Function
     End If

     If Not oExec.StdErr.AtEndOfStream Then
          ReadOutput = oExec.StdErr.ReadAll
          Exit Function
     End If

     ReadOutput = ""
     
End Function

Function GetFinancialModelerDirectory   
    Dim tuamHome
    Dim webPath
        
    tuamHome = GetInstallDirectory() 
    webPath = tuamHome & "\server\financial_modeler"
    
    if (fso.FolderExists(webPath)) Then 
        GetFinancialModelerDirectory = webPath
    else
        WScript.Echo "Error: Financial Modeler Directory not found."
        WScript.Echo "path=" & webPath
        WScript.Quit(GENERAL_FAILURE)    
    end if 
End Function

Function GetWebDirectory   
    Dim tuamHome
    Dim webPath
        
    tuamHome = GetInstallDirectory() 
    webPath = tuamHome & "\server\web2"
    
    if (fso.FolderExists(webPath)) Then    
        GetWebDirectory = webPath
    else
        WScript.Echo "Error: TUAM Web Directory not found."
        WScript.Echo "path=" & webPath 
        WScript.Quit(GENERAL_FAILURE)    
    end if 
End Function

Function GetLogsDirectory   
    Dim tuamHome
    Dim path
        
    tuamHome = GetInstallDirectory() 
    path = tuamHome & "\logs"
    
    if (fso.FolderExists(path)) Then    
        GetLogsDirectory = path
    else
        WScript.Echo "Warning: TUAM Logs Directory not found." 
        WScript.Echo "path=" & path 
    end if 
End Function

Function GetConfigDirectory   
    Dim tuamHome
    Dim path
        
    tuamHome = GetInstallDirectory() 
    path = tuamHome & "\config"
    
    if (fso.FolderExists(path)) Then    
        GetConfigDirectory = path
    else
        WScript.Echo "Warning: TUAM Config Directory not found."
        WScript.Echo "path=" & path  
    end if 
End Function

Function GetReportsMSRS2Directory   
    Dim tuamHome
    Dim path
        
    tuamHome = GetInstallDirectory() 
    path = tuamHome & "\server\reportsmsrs2"
    
    if (fso.FolderExists(path)) Then    
        GetReportsMSRS2Directory = path
    else
        WScript.Echo "Warning: TUAM ReportsMSRS2 Directory not found."
        WScript.Echo "path=" & path    
    end if 
End Function

Function GetInstallDirectory
    Dim tuamHome
    tuamHome = Shell.ExpandEnvironmentStrings("%TUAM_HOME%")
    GetInstallDirectory = tuamHome
End Function

Function IIsMajorVersion
    Dim value
    value = shell.RegRead("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\InetStp\MajorVersion")    
    IIsMajorVersion = Cint(value) 
End Function

Function ObjectExists(path)
    Dim value
    Dim IIsObj
    
    On Error Resume Next
    Set IIsObj = GetObject(path)
    value = (Err.Number = 0)
    Err.Clear()
    Set IIsObj = nothing 
    ObjectExists = value    
End Function

'*****************************
'* Display Help Message
'*****************************
Sub DisplayHelpMessage()
    WScript.Echo
    WScript.Echo "Usage:"
    WScript.Echo "      iisconfig.vbs web2|financialmodeler install|uninstall [default|virtual]"
    WScript.Echo
End Sub
