	// ***********************************************************************************
	// Javascript library for expanding / collapsing lists in Cognos Reports
	//
	// Provided as part of Tivoli Usage and Accounting Manager 7.3.0.4
	// ***********************************************************************************

	// ************************************************************************************
	// Shared Functionality
	// ************************************************************************************
	
	function isPlus(el) {
    	return el.src.indexOf("minus") == -1;
    }
	
	// ************************************************************************************
	// Expand and Collapse Functionality Method 1
	// Standard Expand and Collapse
	// ************************************************************************************
	
    function ExpandCollapse(el) {
    	// change icon
	    el.src = "../pat/hal/images/" + (isPlus(el) ? "minus" : "plus") + ".gif";
    	var tr = el.parentNode.parentNode; // the current row
    	currentRow = tr.rowIndex;

    	DisplayHideRows(el);
    }

    function DisplayHideRows(el) {

	    var displayStyle = "";
        var noDisplayStyle = "none";
	
	    var show = true;  // to show lines or not

	    // Grab the ROW that was clicked and the TABLE that contains it
	    var tr = el.parentNode.parentNode; // the current row
	    var tbl = tr.parentNode.parentNode; // the table
	    var cid = el.parentNode.cellIndex; // the index of the column

	    if (isPlus(el)) {
    		show = false;
    	} else {
		    show = true;
    	}

    	while (currentRow < tbl.rows.length-1) {
    		currentRow++;

    		var trCurrent = tbl.rows[currentRow];
    		var index = findIconInRow(trCurrent, 0); // return the index of the first img 

                    if (index < 0 && tbl.rows[currentRow].cells[0].innerHTML) {
                            index=0;
                    }

        	        if (index >= 0 && index <= cid) {
	    		trCurrent.style.display = displayStyle;
    			currentRow--;
	    		return; // found the next line with icon in the same column; return
	    	}
	    	if (!show) {
	    		trCurrent.style.display = noDisplayStyle;
    		} else {
    			trCurrent.style.display = displayStyle;
    			var iconIndex = findIconInRow(trCurrent, cid + 1);
    			if (Number(iconIndex) > -1) {
    				var icon = trCurrent.cells[iconIndex].firstChild;
    				DisplayHideRows(icon);
    			}
    		}
    	}
    }

    function hasIcon(cell) {
    	// return true if this cell has an img
    	if ((Number(cell.childNodes.length)) == 0) {
    		return false;
    	}
    	var c = cell.firstChild;
    	if (c != null) {
    		return (c.tagName == "IMG");
    	}
    	return false;
    }

    function findIconInRow(trCurrent, cid) {

    	for ( var i = cid; i < trCurrent.cells.length; i++) {
    		if (hasIcon(trCurrent.cells[i])) {
    			return i;
    		}
    	}
    	return -1;
    }

    function HideAllRows() {
     	var q=document.getElementById("ExpandedTable");

     	// get the table
     	tbl = q.parentNode.parentNode.parentNode;

    	var isFirstRow=true;

    	for ( var i = 0; i < tbl.rows.length; i++) {
    		var trCurrent = tbl.rows[i]; // the current row
    		var d = trCurrent.cells[0]; // first cell
    		var c = d.firstChild;
    		if (c != null) {
    			c = c.src; // leave it shown as it has plus icon
    			for ( var j = 1; j < trCurrent.cells.length; j++) {
	    			trCurrent.cells[j].width="1";				
	    		}
	    	}
	    	else {
	    		trCurrent.style.display = "none"; // hide the row
	    	}
    	}
    }
	  
	// ************************************************************************************
	// Expand and Collapse Functionality Method 2
	// Using the Account Level to determine whether to expand or collapse
	// ************************************************************************************	  
	  
    // This function is the main function for expanding and collapsing
    function ExpandCollapseActLevel(el) {
  
     	// change icon
     	el.src = "../pat/hal/images/" + (isPlus(el) ? "minus" : "plus") + ".gif";
     	var tr = el.parentNode.parentNode; // the current row
     	currentRow = tr.rowIndex;

     	// Get the level of the current row 
     	if(!hasInnerText)
     	{
     	  var origLevel = Number(tr.cells[1].textContent);
     	} 
     	else
     	{
     	  var origLevel = Number(tr.cells[1].innerText );
     	}
     	DisplayHideRowsActLevel(el,origLevel );
  	 }

  	 // function to loop through the subsequent rows from the current row and hide or show them
  	 function DisplayHideRowsActLevel(el,lev) {

       	// Display Styles
     	var displayStyle = "";
     	var noDisplayStyle = "none";
  
     	// Variable to determine whether to show or hide
     	var show = true;  

     	// get the row that was clicked
     	var tr = el.parentNode.parentNode; // Current row
     	var tbl = tr.parentNode.parentNode; // Table

     	// work out if we need to expand or collapse
     	if (isPlus(el)) 
     	{
          show = false;
     	} 
     	else 
     	{
     	  show = true;
     	}

     	// Loop through subsequent rows
     	while (currentRow < tbl.rows.length-1) 
     	{
     	  currentRow++;
     	var trCurrent = tbl.rows[currentRow];
           
     	// get account level of current row
     	actLevel = trCurrent.cells[1].textContent;
     	if(!hasInnerText)
     	{
     	  actLevel = trCurrent.cells[1].textContent;
     	} 
     	else
     	{
     	  actLevel = trCurrent.cells[1].innerText;
     	}

     	// If account level is the same as the cell that was clicked then exit
     	if (actLevel==lev)
     	{return;}

     	// When expanding only expand the next account level records 
     	if (actLevel==(lev+1) && show)
     	{
     	  trCurrent.style.display = displayStyle;
     	}

     	// When collapsing, only hide those rows of an account level greater than the account level clicked
     	if (actLevel>lev && !show)
     	{
     	  trCurrent.childNodes[0].childNodes[1].src = "../pat/hal/images/plus.gif";
     	  trCurrent.style.display = noDisplayStyle;                }
     	}
    }

    // Function to initially only show the account level 1 records
    function HideAllRowsActLevel() {
    
	  var q=document.getElementById("ExpandedTable");

	  // get the table
	  tbl = q.parentNode.parentNode.parentNode;

	  // Hide the Account Level column title
	  tbl.rows[0].childNodes[1].style.display="none";

	  for ( var i = 1; i < tbl.rows.length; i++) {
	    var trCurrent = tbl.rows[i]; // Current row
	    var d = trCurrent.cells[0]; // First cell

      // Hide the Account Level column (so it can still be referenced)
      tbl.rows[i].childNodes[1].style.display="none";

      // Get the Account Level for the row
      if(!hasInnerText)
      {
        lev=tbl.rows[i].childNodes[1].textContent;
        
        // Issue with left justification in firefox
        trCurrent.cells[0].classList.remove("lm");
        trCurrent.cells[0].style.padding = "3px 5px";
      } 
      else
      {
        lev=tbl.rows[i].childNodes[1].innerText ;
      }

      // If not the first account level then hide
      if (lev==1) 
      {
        for ( var j = 1; j < trCurrent.cells.length; j++) 
        {
          trCurrent.cells[j].width="1";				
        }
      }
      else 
      {
        trCurrent.style.display = "none"; 
      }
    }
  }

  // Variables for Expand and Collapse
  var currentRow = 0;	
  var origLevel = 0;

  // Firefox and IE difference
  var hasInnerText =(document.getElementsByTagName("body")[0].innerText != undefined) ? true : false;
	
  // Get Document Handle as Global
  var fWR = (typeof getFormWarpRequest == "function" ?
  getFormWarpRequest() : document.forms["formWarpRequest"]);
  if ( !fWR || fWR == undefined) { fWR = ( formWarpRequest_THIS_ ?
    formWarpRequest_THIS_ : formWarpRequest_NS_ );}

	  
	  
	  