#!/bin/sh

basedir=`pwd`

user=tipadmin
passwd=tippass
if [ ! -z "$1" ]; then
	user=$1
fi
if [ ! -z "$2" ]; then
	passwd=$2
fi
base="7.3.0"
fixpack="4"

echo "Searching for installed components..."

de=""
for dir in $SI_PATH/bin $HOME/.acsi_$USER/bin /usr/ibm/common/acsi/bin
do
	if [ -x $dir/de_lsrootiu.sh ]; then
		de=$dir
		break
	fi
done
if [ -z "$de" ]; then
	echo "Unable to find DE"
	exit 1
fi

patched=0
oifs="$IFS"
tipinfo=`$de/de_lsrootiu.sh | grep "IU,TIPCore" | awk -F, '{print $4 " " $5}'`
set -- $tipinfo
tipver=$1
TIP_HOME=$2

${TIP_HOME}/profiles/TIPProfile/bin/serverStatus.sh server1 -username $user -password $passwd | grep -q ADMU0508I
if [ $? -ne 0 ]; then
	echo "Unable to check TIP server status - please ensure server is running"
	echo "and check $user password is correct."
	echo
	echo "usage: $0 tipadmin password"
	exit 1
fi

$de/de_lsrootiu.sh | grep "IU,TUAM_" | sort | (while read line
do
	oifs="$IFS"
    IFS=","
	set `echo "$line" | awk -F, '{print $2 "," $4 "," $5 "," $6}' | sed 's/]<.*//'`
	IFS="$oifs"
	component=$1
	version=$2
	disc=$3
	uuid=$4
	[ -x $disc/bin/setupEnv.sh ] && . $disc/bin/setupEnv.sh
	if [ "$version" == "${base}.${fixpack}" ] && [ -d $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component ]; then
		echo "Undoing patch for $component"
		cd $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component
		if [ "$component" == "TUAM_UI" ]; then
			# As the non-fixpack deploy script doesn't redeploy collector jars, we want to keep the
			# fixpack one around until we have redeployed the original 7.3.0 war.
			cp $TUAM_HOME/setup/console/deployTuam.sh $TUAM_HOME/setup/console/deployTuam_fp1.sh
			cp $TUAM_HOME/setup/console/deployTUAMConsole.py $TUAM_HOME/setup/console/deployTUAMConsole_fp1.py
			cat > var.properties <<EOF
Variable#RootIUTypeID[${uuid},${base}.${fixpack}]#IAGLOBAL_TIP_HOME=${TIP_HOME}
Variable#RootIUTypeID[${uuid},${base}.${fixpack}]#shExt=sh
EOF
			$de/manageIU.sh -o undo -i var.properties -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			status=$?
			rm -f var.properties
			if [ $status -eq 0 ]; then
				mv $TUAM_HOME/setup/console/deployTUAMConsole.py $TUAM_HOME/setup/console/deployTUAMConsole_fp0.py
				mv $TUAM_HOME/setup/console/deployTUAMConsole_fp1.py $TUAM_HOME/setup/console/deployTUAMConsole.py
				chmod a+x $TUAM_HOME/setup/console/deployTuam*.sh
				$TUAM_HOME/setup/console/deployTuam_fp1.sh replace $user $passwd >> $TUAM_HOME/logs/fp_${component}.log 2>&1
				status=$?
				mv $TUAM_HOME/setup/console/deployTUAMConsole_fp0.py $TUAM_HOME/setup/console/deployTUAMConsole.py
			else
				rm -f $TUAM_HOME/setup/console/deployTUAMConsole_fp1.py
			fi
			rm -f $TUAM_HOME/setup/console/deployTuam_fp1.sh
			if [ $status -eq 0 ]; then
				if [ -f $TUAM_HOME/_uninst/fixes/fp${fixpack}/SMUtils.js ]; then
					mv $TUAM_HOME/_uninst/fixes/fp${fixpack}/SMUtils.js ${TIP_HOME}/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/SMUtils.js
				fi
				if [ -f $TUAM_HOME/_uninst/fixes/fp${fixpack}/tipregistry.txt ]; then
					oldv=`cat $TUAM_HOME/_uninst/fixes/fp${fixpack}/tipregistry.txt`
					${TIP_HOME}/profiles/TIPProfile/bin/tipRegister.sh 081F67AF608643DE937B00F6A41D9083 TUAM $TUAM_HOME ${oldv} product none false >> $TUAM_HOME/logs/fp_${component}.log 2>&1
					status=$?
					rm -f $TUAM_HOME/_uninst/fixes/fp${fixpack}/tipregistry.txt
				else
					${TIP_HOME}/profiles/TIPProfile/bin/tipDeregister.sh 081F67AF608643DE937B00F6A41D9083 >> $TUAM_HOME/logs/fp_${component}.log 2>&1
					status=$?
				fi
			fi
		else
			$de/manageIU.sh -o undo -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			status=$?
		fi
		cd $TUAM_HOME
		if [ $status -ne 0 ]; then
			echo "Undo failed"
			exit 1
		else
			rm -rf $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component
		fi
		patched=1
	fi
done
if [ $patched -eq 0 ]; then
   echo "TUAM Release ${base}.${fixpack} must be installed to remove this fix pack."
   echo "Please install this version before attempting to remove this fix pack."
   echo "Fix has not been unapplied successfully."
   exit 1
fi
)
